@@ -22,6 +22,7 @@ from botocore.response import StreamingBody
 from .paginator import ListRetainedMessagesPaginator
 from .type_defs import (
     DeleteThingShadowResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetRetainedMessageResponseTypeDef,
     GetThingShadowResponseTypeDef,
     ListNamedShadowsForThingResponseTypeDef,
@@ -154,7 +155,7 @@ class IoTDataPlaneClient(BaseClient):
         qos: int = ...,
         retain: bool = ...,
         payload: Union[str, bytes, IO[Any], StreamingBody] = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Publishes an MQTT message.
 
